
.. _onnx-tutorial:

Introduction to ONNX
====================

This documentation describes the ONNX concepts (**Open Neural Network Exchange**).
It shows how it is used with examples in python and finally explains
some of challenges faced when moving to ONNX in production.

.. toctree::
    :maxdepth: 2

    concepts
    python
    converters
